django-contact-form 1.4 — django-contact-form 1.4 documentation

# django-contact-form 1.4

`django-contact-form` provides customizable contact-form functionality for Django-powered Web sites.

Basic functionality (collecting a name, email address and message) can be achieved out of the box by setting up a few templates and adding one line to your site’s root URLconf:

    url(r'^contact/', include('contact_form.urls')),

For notes on getting started quickly, and on how to customize `django-contact-form`’s behavior, read through the full documentation below.

Contents:

Installation and configuration

- Installation guide
- Quick start guide
- URL configuration
- Required templates

For developers

- Contact form classes
- Built-in views

Other documentation

- Frequently asked questions